[llvm-commits] [llvm] r90807 - in /llvm/trunk: include/llvm/Analysis/DebugInfo.h lib/Analysis/DebugInfo.cpp

Victor Hernandez vhernandez at apple.com
Mon Dec 7 13:54:43 PST 2009


Author: hernande
Date: Mon Dec  7 15:54:43 2009
New Revision: 90807

URL: http://llvm.org/viewvc/llvm-project?rev=90807&view=rev
Log:
Rename DIFactory::InsertValue() as DIFactory::InsertDbgValueIntrinsic()

Modified:
    llvm/trunk/include/llvm/Analysis/DebugInfo.h
    llvm/trunk/lib/Analysis/DebugInfo.cpp

Modified: llvm/trunk/include/llvm/Analysis/DebugInfo.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Analysis/DebugInfo.h?rev=90807&r1=90806&r2=90807&view=diff

==============================================================================
--- llvm/trunk/include/llvm/Analysis/DebugInfo.h (original)
+++ llvm/trunk/include/llvm/Analysis/DebugInfo.h Mon Dec  7 15:54:43 2009
@@ -662,13 +662,13 @@
     Instruction *InsertDeclare(llvm::Value *Storage, DIVariable D,
                                Instruction *InsertBefore);
 
-    /// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-    Instruction *InsertValue(llvm::Value *V, llvm::Value *Offset,
-                             DIVariable D, BasicBlock *InsertAtEnd);
-
-    /// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-    Instruction *InsertValue(llvm::Value *V, llvm::Value *Offset,
-                             DIVariable D, Instruction *InsertBefore);
+    /// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+    Instruction *InsertDbgValueIntrinsic(llvm::Value *V, llvm::Value *Offset,
+                                         DIVariable D, BasicBlock *InsertAtEnd);
+
+    /// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+    Instruction *InsertDbgValueIntrinsic(llvm::Value *V, llvm::Value *Offset,
+                                       DIVariable D, Instruction *InsertBefore);
   private:
     Constant *GetTagConstant(unsigned TAG);
   };

Modified: llvm/trunk/lib/Analysis/DebugInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Analysis/DebugInfo.cpp?rev=90807&r1=90806&r2=90807&view=diff

==============================================================================
--- llvm/trunk/lib/Analysis/DebugInfo.cpp (original)
+++ llvm/trunk/lib/Analysis/DebugInfo.cpp Mon Dec  7 15:54:43 2009
@@ -1078,9 +1078,10 @@
   return CallInst::Create(DeclareFn, Args, Args+2, "", InsertAtEnd);
 }
 
-/// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
-                                    Instruction *InsertBefore) {
+/// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+Instruction *DIFactory::InsertDbgValueIntrinsic(Value *V, Value *Offset,
+                                                DIVariable D,
+                                                Instruction *InsertBefore) {
   assert(V && "no value passed to dbg.value");
   assert(Offset->getType() == Type::getInt64Ty(V->getContext()) &&
          "offset must be i64");
@@ -1093,9 +1094,10 @@
   return CallInst::Create(ValueFn, Args, Args+3, "", InsertBefore);
 }
 
-/// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
-                                    BasicBlock *InsertAtEnd) {
+/// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+Instruction *DIFactory::InsertDbgValueIntrinsic(Value *V, Value *Offset,
+                                                DIVariable D,
+                                                BasicBlock *InsertAtEnd) {
   assert(V && "no value passed to dbg.value");
   assert(Offset->getType() == Type::getInt64Ty(V->getContext()) &&
          "offset must be i64");





More information about the llvm-commits mailing list